@@ -6,7 +6,7 @@ use std::thread;
 use std::time::Duration;
 
 #[cfg(feature = "use_sync")]
-use syslog_rs::sy_sync::{Syslog};
+use syslog_rs::sy_sync::{Syslog, SyslogCommon};
 
 use syslog_rs::{LogStat, LogFacility, Priority};
 
