@@ -50,44 +50,48 @@
 //! 
 //! By default, all 3 features are enabled.
 
-#[macro_use] extern crate bitflags;
+//-- REEXPORT --
+#[macro_use] 
+extern crate bitflags;
 #[cfg(any(feature = "use_sync", feature = "use_sync_queue"))]
 extern crate crossbeam;
 extern crate chrono;
 extern crate nix;
-//extern crate libc;
-#[macro_use] extern crate lazy_static;
+#[macro_use] 
+extern crate lazy_static;
 
+//-- ASYNC --
 #[cfg(feature = "use_async")]
 extern crate async_recursion;
 #[cfg(feature = "use_async")]
 extern crate tokio;
 
-pub mod syslog_sync_internal;
-
+//-- SYNC --
 #[cfg(feature = "use_sync")]
-pub mod syslog_sync;
+pub mod sync;
 #[cfg(feature = "use_async")]
-pub mod syslog_async;
-#[cfg(feature = "use_sync_queue")]
-pub mod syslog_sync_queue;
+pub mod a_sync;
 
-#[cfg(any(feature = "use_sync", feature = "use_sync_queue"))]
-pub mod socket;
-#[cfg(feature = "use_async")]
-pub mod async_socket;
+//-- NON EXPORT
+mod portable;
 
+
+//-- PUBLIC 
 pub mod unsafe_cell;
-#[macro_use] pub mod common;
-#[macro_use] pub mod error;
-pub mod portable;
 
+#[macro_use] 
+pub mod common;
+#[macro_use] 
+pub mod error;
+
+//#[cfg(any(feature = "use_sync", feature = "use_sync_queue"))]
+//pub use sync::syslog_trait::SyslogCommon;
 #[cfg(feature = "use_sync")]
-pub use syslog_sync as sy_sync;
+pub use sync::syslog_sync as sy_sync;
 #[cfg(feature = "use_async")]
-pub use syslog_async as sy_async;
+pub use a_sync::syslog_async as sy_async;
 #[cfg(feature = "use_sync_queue")]
-pub use syslog_sync_queue as sy_sync_queue;
+pub use sync::syslog_sync_queue as sy_sync_queue;
 
 pub use common::*;
 pub use unsafe_cell::*;
