@@ -34,7 +34,7 @@ impl<T: Send> ops::Deref for UnsafeReadOnlyCell<T>
     type Target = T;
     fn deref(&self) -> &T 
     {
-        if self.blocked.load(Ordering::SeqCst) == false
+        if self.blocked.load(Ordering::Relaxed) == false
         {
             panic!("Assertion trap: Dereference attempt of UnsafeReadOnlyCell \
                     '{}' which was not inited.", self.title);
@@ -47,6 +47,7 @@ impl<T: Send> ops::Deref for UnsafeReadOnlyCell<T>
     }
 }
 
+
 impl<T: Send> UnsafeReadOnlyCell<T>
 {
     /// Creates new unititialized Cell.
@@ -95,15 +96,14 @@ impl<T: Send> UnsafeReadOnlyCell<T>
     pub unsafe 
     fn init(&self, init: T) 
     {
-        if self.blocked.load(Ordering::SeqCst) == false
+        if self.blocked.swap(true, Ordering::AcqRel) == false
         {
             (*self.inner.get()) = MaybeUninit::new(init);
-            self.blocked.store(true, Ordering::SeqCst);
         }
         else
         {
             panic!("Assertion trap: attempt to re-initialize \
-                    the ReadOnlySharedCell: {}", self.title);
+                the ReadOnlySharedCell: {}", self.title);
         }
     }
 
