@@ -6,7 +6,7 @@ fn test_cell()
     use std::time::{Instant, Duration};
 
     #[cfg(feature = "use_sync")]
-    use syslog_rs::sy_sync::{Syslog};
+    use syslog_rs::sy_sync::{Syslog, SyslogCommon};
     use syslog_rs::{LogStat, LogFacility, Priority, UnsafeReadOnlyCell};
 
     lazy_static! {
@@ -41,7 +41,7 @@ fn test_cell()
     
     logdebug!("test message!");
     logdebug!("test message2!");
-    (*SYNC_SYSLOG).change_identity("test111");
+    let _ = (*SYNC_SYSLOG).change_identity("test111");
     logdebug!("test message!");
     
     thread::sleep(Duration::from_micros(10));
